import { createRouter, createWebHashHistory } from 'vue-router'

const routes = [
  {
    path: '/',
    redirect: '/home'
  },
  {
    name: 'login',
    path: '/login',
    component: () => import('../views/login'),
    meta: {
      title: '登录',
    },
  },
  {
    name: 'home',
    path: '/home',
    component: () => import('../views/home'),
    meta: {
      title: '首页',
    },
  },
  {
    path: '/user',
    component: () => import('../views/user/index.vue'),
    children: [
      {
        name: 'userAccount',
        path: 'account',
        component: () => import('../views/user/account.vue'),
        meta: {
          title: '账号中心',
        },
      },
      {
        name: 'userPassWord',
        path: 'password',
        component: () => import('../views/user/password.vue'),
        meta: {
          title: '更改密码',
        },
      },
      {
        name: 'userMobile',
        path: 'mobile',
        component: () => import('../views/user/mobile.vue'),
        meta: {
          title: '手机号',
        },
      },
    ]
  },
  {
    path: '/repair',
    component: () => import('../views/repair/index.vue'),
    children: [
      {
        name: 'repairOnline',
        path: 'create',
        component: () => import('../views/repair/create.vue'),
        meta: {
          title: '线上报修',
        },
      },
      {
        name: 'repairList',
        path: 'list',
        component: () => import('../views/repair/list.vue'),
        meta: {
          title: '工单待办',
        },
      },
      {
        name: 'repairDetail',
        path: 'detail',
        component: () => import('../views/repair/detail.vue'),
        meta: {
          title: '工单详情',
        },
      },
    ]
  },
  {
    path: '/review',
    component: () => import('../views/review/index.vue'),
    children: [
      {
        name: 'reviewRecord',
        path: 'list',
        component: () => import('../views/review/list.vue'),
        meta: {
          title: '巡检记录',
        },
      },
      {
        name: 'reviewClock',
        path: 'clock',
        component: () => import('../views/review/clock.vue'),
        meta: {
          title: '巡检打卡',
        },
      },
    ]
  },
  {
    path: '/bill',
    component: () => import('../views/bill/index.vue'),
    children: [
      {
        name: 'billList',
        path: 'list',
        component: () => import('../views/bill/list.vue'),
        meta: {
          title: '租户账单',
        },
      },
      {
        name: 'billDetail',
        path: 'detail',
        component: () => import('../views/bill/detail.vue'),
        meta: {
          title: '账单明细',
        },
      },
    ]
  },
  {
    path: '/pay',
    component: () => import('../views/pay/index.vue'),
    children: [
      {
        name: 'payRecord',
        path: 'record',
        component: () => import('../views/pay/record.vue'),
        meta: {
          title: '扣缴记录',
        },
      },
      {
        name: 'payFee',
        path: 'fee',
        component: () => import('../views/pay/fee.vue'),
        meta: {
          title: '欠费待收',
        },
      },
    ]
  },
  {
    path: '/device',
    component: () => import('../views/device/index.vue'),
    children: [
      {
        name: 'deviceAlarm',
        path: 'list',
        component: () => import('../views/device/list.vue'),
        meta: {
          title: '设备异常',
        },
      },
    ]
  },
  {
    name: 'remoteControl',
    path: '/remoteControl',
    component: () => import('../views/remoteControl'),
    meta: {
      title: '远程管控',
    },
  },
  {
    name: 'WeChat',
    path: '/WeChat',
    component: () => import('../views/bill/WeChat'),
    meta: {
      title: '微信支付',
    },
  },
  {
    name: 'Alipay',
    path: '/Alipay',
    component: () => import('../views/bill/Alipay'),
    meta: {
      title: '支付宝支付',
    },
  },
  {
    name: 'payFinished',
    path: '/payFinished',
    component: () => import('../views/bill/payFinished'),
    meta: {
      title: '支付完成',
    },
  },
  {
    name: 'AliPayFinished',
    path: '/AliPayFinished',
    component: () => import('../views/bill/AliPayFinished'),
    meta: {
      title: '支付完成',
    },
  },
  {
    title: '扫码页面',
    name: 'scanCode',
    path: '/scanCode',
    component: () => import('../views/scanCode.vue')
  }
]

const router = createRouter({
  history: createWebHashHistory(),
  routes
})
// 全局前置守卫，设置页面标题
router.beforeEach((to, from, next) => {
  // const title = to.meta && to.meta.title;
  // if (title) {
  //   document.title = title;
  // }
  document.title = '双碳感知资产运营管理平台';
  next(); //必须写
});

export default router
